@@ -37,9 +37,10 @@
 */
 #include "magick/studio.h"
 #include "magick/blob.h"
-#include "magick/pixel_cache.h"
+#include "magick/colormap.h"
 #include "magick/magick.h"
 #include "magick/monitor.h"
+#include "magick/pixel_cache.h"
 #include "magick/utility.h"
 
 /*
@@ -143,6 +144,10 @@ static Image *ReadPIXImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if (image_info->ping && (image_info->subrange != 0))
       if (image->scene >= (image_info->subimage+image_info->subrange-1))
         break;
+
+    if (CheckImagePixelLimits(image, exception) != MagickPass)
+      ThrowReaderException(ResourceLimitError,ImagePixelLimitExceeded,image);
+
     /*
       Convert PIX raster image to pixel packets.
     */
@@ -156,7 +161,7 @@ static Image *ReadPIXImage(const ImageInfo *image_info,ExceptionInfo *exception)
       q=SetImagePixels(image,0,y,image->columns,1);
       if (q == (PixelPacket *) NULL)
         break;
-      indexes=GetIndexes(image);
+      indexes=AccessMutableIndexes(image);
       for (x=0; x < (long) image->columns; x++)
       {
         if (length == 0)
@@ -182,7 +187,9 @@ static Image *ReadPIXImage(const ImageInfo *image_info,ExceptionInfo *exception)
       if (!SyncImagePixels(image))
         break;
       if (image->previous == (Image *) NULL)
-        if (!MagickMonitor(LoadImageText,y,image->rows,exception))
+        if (!MagickMonitorFormatted(y,image->rows,exception,LoadImageText,
+                                    image->filename,
+                                    image->columns,image->rows))
           break;
     }
     if (image->storage_class == PseudoClass)
@@ -218,7 +225,8 @@ static Image *ReadPIXImage(const ImageInfo *image_info,ExceptionInfo *exception)
             return((Image *) NULL);
           }
         image=SyncNextImageInList(image);
-        if (!MagickMonitor(LoadImagesText,TellBlob(image),GetBlobSize(image),exception))
+        if (!MagickMonitorFormatted(TellBlob(image),GetBlobSize(image),exception,
+                                    LoadImagesText,image->filename))
           break;
       }
   } while (status == True);
@@ -258,8 +266,8 @@ ModuleExport void RegisterPIXImage(void)
 
   entry=SetMagickInfo("PIX");
   entry->decoder=(DecoderHandler) ReadPIXImage;
-  entry->description=AcquireString("Alias/Wavefront RLE image format");
-  entry->module=AcquireString("PIX");
+  entry->description="Alias/Wavefront RLE image format";
+  entry->module="PIX";
   (void) RegisterMagickInfo(entry);
 }
 
